
// MODEL NUMBER: 0190 at www.physiome.org [JBBass74]
// MODEL NAME: BTEX20simple
// SHORT DESCRIPTION: Simple Model of an axially distributed two-region
//    capillary Blood-Tissue EXchange unit with consumption in interstitium

import  nsrunit; unit conversion on;

math btex20simple {

//   INDEPENDENT VARIABLES:
realDomain t sec ; t.min = 0; t.max = 30; t.delta = 0.1;
realDomain x cm; real L= 0.1 cm, Ngrid = 31; x.min = 0; x.max = L; x.ct = Ngrid;    

//   Parameters and Keys to Names:
real Fcap   = 1 ml/(g*min),    // Capillary (cap) plasma flow
     Vcap   = 0.05 ml/g,       // Capillary Volume
     Visf   = 0.15 ml/g,       // Interstitial Fluid (isf) Volume
     PS     = 1 ml/(g*min),    // Permeability-surface area product: cap <--> isf                                               
     Gisf   = 0 ml/(g*min),     // consumption rate in isf region (Gulosity)
     Dcap   = 1.0e-5 cm^2/sec,  // cap axial diffusion coefficient
     Disf    = 1.0e-6 cm^2/sec; // isf axial diffusion coefficient
//   Inflow Concentration,  Input Function:
extern real Cin(t) mM;
//   Concentration Variables:
real Ccap(t,x)  mM,            // capillary concentration at position x
     Cisf(t,x)  mM,            // isf       concentration at position x
     Cout(t)    mM;            // Outflow Concentration from capillary at x=L

//   Boundary Conditions: (Note total flux BC for inflowing region.)  
when (x=x.min) { (-Fcap*L/Vcap)*(Ccap-Cin)+Dcap*Ccap:x = 0; Cisf:x = 0; }
when (x=x.max) { Ccap:x = 0; Cisf:x = 0; Cout = Ccap; }  // reflecting boundary
//   Initial Conditions:
when (t=t.min)   { Ccap   = 0; Cisf   = 0; }  // sets initial concentrations to zero

//   Partial Differential Equations: Ccap:t is dCcap/dt in JSim's MML (ODE or PDE)
     Ccap:t = -Fcap*L*Ccap:x/Vcap + Dcap*Ccap:x:x + PS*(Cisf-Ccap)/Vcap; // dCcap/dt
     Cisf:t   = -Gisf*Cisf/Visf            + Disf*Cisf:x:x     + PS*(Ccap-Cisf)/Visf;  // dCisf/dt
}       //program end
/*
COPYRIGHT AND REQUEST FOR ACKNOWLEDGMENT OF USE:   
  Copyright (C) 1999-2013 University of Washington. From the National Simulation Resource,  
  Director J. B. Bassingthwaighte, Department of Bioengineering, University of Washington, Seattle WA 98195-5061. 
  Academic use is unrestricted. Software may be copied so long as this copyright notice is included.
  
  This software was developed with support from NIH grant HL073598. 
  Please cite this grant in any publication for which this software is used and send an email 
  with the citation and, if possible, a PDF file of the paper to: staff@physiome.org. 
*/
