
// Model Name: MM2irrev     (From reference JBBass13, data of Escribano [Escribano88])
/* Brief Description:  The MM2irrev program codes a sequential pair of irreversible Michaelis-Menten enzymatic reactions, Hx -> Xa -> Ua, wherein the one enzyme, Xanthine Oxidase, serves both steps. Hx and Xa compete for its active site.  */

import nsrunit; unit conversion on;

math MM2irrev {                            
    realDomain t sec; t.min=0; t.max=5000.0; t.delta=1.00;  // t is independent variable

// PARAMETERS:      (denoted param(t) if time-variable) (all changeable at run-time)
	real Vhmax = 1.84 uM/s;     // Vmax for enzymatic conversion of Hx -> Xa
	real Kmh     = 3.67 uM;     // Km for assumed instant binding of Hx to enzyme
	real Vxmax = 1.96 uM/s;     // Vmax for Xa -> Ua
	real Kmx     = 5.94 uM;     // Km for assumed instant binding of Xa to enzyme
        real Hzero   = 46.3 uM,   Xzero = 0 uM,    Uzero = 0 uM;  // initial conditions

// VARIABLES      (specified as functions of time by (t) appended in defining the name)
	real H(t) uM;              // concentration of Hx (HypoXanthine)
	real X(t) uM;              // concentration of Xa (Xanthine)
	real U(t) uM;              // concentration of Ua (Uric acid)

// INITIAL CONDITIONS   (t.min can differ from t = 0 sec.)
        when (t=t.min){ H= Hzero; X = Xzero; U = Uzero;}

// SYSTEM OF EQUATIONS (3 ODEs)   (Derivative dH/dt written as H:t)
     H:t = - (Vhmax*H/Kmh) / (1 + H/Kmh + X/Kmx);                     // Hx-> Xa
     X:t = ((Vhmax*H/Kmh) - (Vxmax*X/Kmx)) / (1 + H/Kmh + X/Kmx);     // X ->
     U:t =  (Vxmax*X/Kmx) / (1 + H/Kmh + X/Kmx);                      //   -> Ua 

} // PROGRAM END
/*
COPYRIGHT AND REQUEST FOR ACKNOWLEDGMENT OF USE:   
  Copyright (C) 1999-2013 University of Washington. From the National Simulation Resource,  
  Director J. B. Bassingthwaighte, Department of Bioengineering, University of Washington, Seattle WA 98195-5061. 
  Academic use is unrestricted. Software may be copied so long as this copyright notice is included.
  
  This software was developed with support from NIH grant HL073598. 
  Please cite this grant in any publication for which this software is used and send an email 
  with the citation and, if possible, a PDF file of the paper to: staff@physiome.org. 
*/

